@@ -19,7 +19,6 @@ workers_long_running = "Workers are active for too long. Going to process as wel
 state_table = "workerState"
 failure_table = "executionFailures"
 segment_failure_table = "segmentExecutionFailures"
-wake_up_queue_name = "wake-up"
 
 input_container = "input"
 output_container = "output"
@@ -78,26 +77,18 @@ def singleton(class_):
 
 
 class Worker:
-    def __init__(self, queue_name, metadata_table_name, worker_name, should_wake_up=False, segment_limit=200):
-        connection_string = os.environ['AzureWebJobsStorage']
+    def __init__(self, queue_name, metadata_table_name, worker_name, segment_limit=200):
+        self.connection_string = os.environ['AzureWebJobsStorage']
         self.metadata_table_name = metadata_table_name
-        self.table_client = TableService(connection_string=connection_string)
-        self.queue = QueueClient.from_connection_string(conn_str=connection_string, queue_name=queue_name)
-        if should_wake_up:
-            self.wake_up_queue = QueueClient.from_connection_string(conn_str=connection_string, queue_name=wake_up_queue_name)
-        self.should_wake_up = should_wake_up
+        self.table_client = TableService(connection_string=self.connection_string)
+        self.queue = QueueClient.from_connection_string(conn_str=self.connection_string, queue_name=queue_name)
         self.worker_name = worker_name
-        if 'LtbCloudComponentsStorage' in os.environ:
-            self.ltb_connection_string = os.environ['LtbCloudComponentsStorage']
-        else:
-            self.ltb_connection_string = None
         self.segment_limit = segment_limit
         self.pool = ThreadPool(processes=1)
 
     def trigger_blob(self, blob_name, data=None):
         request_id = self._insert_blob_metadata(blob_name, data)
         self._enqueue(request_id)
-        self._wake_up()
         return request_id
     
     def trigger_blobs(self, blob_names: List[str], data=None):
@@ -107,13 +98,11 @@ class Worker:
             request_id = self._insert_blob_metadata(blob_name, data, guid)
             self._enqueue(request_id)
             request_ids.append(request_id)
-        self._wake_up()
         return request_ids
 
     def trigger(self, data):
         request_id = self._insert_request_metadata(data)
         self._enqueue(request_id)
-        self._wake_up()
         return request_id
         
     def get_result(self, request_id):
@@ -168,10 +157,7 @@ class Worker:
                 self._process_blob(request_id, request_entity, blob_func)
         except Exception as e:
             self._record_request_failure(request_entity, e)
-            if self.ltb_connection_string is not None:
-                self._record_failure(request_id, e)
-            else:
-                raise
+            self._record_failure(request_id, e)
 
     def _process_blob(self, request_id, request_entity, func):
         blob_name, params, offset, retry_count, batch_count, next_chunk = self._read_metadata(request_entity)
@@ -219,10 +205,10 @@ class Worker:
             self.table_client.update_entity(self.metadata_table_name, request_entity)
 
     def _get_input_blob(self, blob_name):
-        return BlobClient.from_connection_string(self.ltb_connection_string, container_name=input_container, blob_name=blob_name)
+        return BlobClient.from_connection_string(self.connection_string, container_name=input_container, blob_name=blob_name)
 
     def _get_output_blob(self, blob_name):
-        return BlobClient.from_connection_string(self.ltb_connection_string, container_name=output_container, blob_name=blob_name)
+        return BlobClient.from_connection_string(self.connection_string, container_name=output_container, blob_name=blob_name)
 
     def _read_metadata(self, request_entity):
         blob_name = request_entity['BlobName']
@@ -288,20 +274,19 @@ class Worker:
     def _record_failure(self, request_id, e: Exception):
         track = traceback.format_exc()
         function_failure_entity = {"PartitionKey": self.worker_name, "RowKey": request_id, "FailureMessage": str(e), "StackTrace": track}
-        TableService(connection_string=self.ltb_connection_string).insert_entity(failure_table, function_failure_entity)
+        self.table_client.insert_entity(failure_table, function_failure_entity)
 
     def _record_segment_failures(self, request_id, blob_name, failures):
         batch, count = TableBatch(), 0
-        table = TableService(connection_string=self.ltb_connection_string)
         for start, end, reason in failures:
             entity = {"PartitionKey": "%s_%s" % (self.worker_name, request_id), "RowKey": "%d_%d" % (start, end), "FailureMessage": reason, "Start": start, "End": end}
             batch.insert_or_replace_entity( entity)
             count += 1
             if count == 99:
-                table.commit_batch(segment_failure_table, batch)
+                self.table_client.commit_batch(segment_failure_table, batch)
                 batch = TableBatch()
         if count > 0:
-            table.commit_batch(segment_failure_table, batch)
+            self.table_client.commit_batch(segment_failure_table, batch)
 
     def _record_request_failure(self, request_entity, e: Exception):
         trace = traceback.format_exc()
@@ -336,10 +321,6 @@ class Worker:
         request_entity['Result'] = json.dumps(response)
         self.table_client.update_entity(self.metadata_table_name, request_entity)
 
-    def _wake_up(self):
-        if self.should_wake_up:
-            self.wake_up_queue.send_message("d2FrZSB1cA==")
-
     @staticmethod
     def _read_blob_by_chunks(input_blob):
         blob_data = input_blob.download_blob()
